@@ -39,14 +39,6 @@ char *mimetype;
 #define xalloc malloc
 #define xfree free
 
-void my_usleep(int usec)
-{
-  struct timeval timeout;
-  timeout.tv_sec=0;
-  timeout.tv_usec=usec;
-  select(0,0,0,0,&timeout);
-}
-
 static void my_kill(int pid)
 {
   if(!kill(pid, SIGTERM))
@@ -55,10 +47,10 @@ static void my_kill(int pid)
      * sleep on it and try again tomorrow..
      */
     D("killing %d\n",pid);
-    my_usleep(4000);
+    usleep(4000);
     if(!kill(pid, SIGTERM))
     {
-      my_usleep(4000);
+      usleep(4000);
       if(!kill(pid, SIGTERM))
       {
 	/* We have failed to kill our children a third time -
@@ -367,7 +359,7 @@ static void my_xlockwindow(Display *dpy,
 	INC_TIME(&tv, 0, 10000 + (rand() & 16383));
 	break;
       }
-      my_usleep((rand() & 16383) + 2000); /* 0.18383 seconds */
+      usleep((rand() & 16383) + 2000); /* 0.18383 seconds */
     }
     
     D("XChangeProperty, mode=%d\n",mode);
@@ -619,7 +611,7 @@ int main(int argc, char **argv)
 	      break;
 	    }
 
-	    my_usleep(2000); /* 1/50 second */
+	    usleep(2000); /* 1/50 second */
 	  }
 	  if(!unlock_done)
 	  {
@@ -657,7 +649,7 @@ int main(int argc, char **argv)
 	  D("Waiting for godot... %d\n",pid);
 	  if(flags & H_EXITS)
 	  {
-	    sleep(0x7fffffff);
+	    exit(0);
 	  }else{
 	    if(waitpid(pid,&status,0) > 0)
 	      waitpid_done++;
@@ -678,7 +670,7 @@ int main(int argc, char **argv)
 	}
 	D("exited ok!\n");
       }
-      if(loops < MAXINT)
+      if(repeats < MAXINT)
 	repeats-=loops;
     }
   }
