@@ -456,9 +456,9 @@ static void do_read_config(void)
   }
   D("do_read_config done\n");
 
-  find_helper_file("mozplugger-" VERSION, find_plugger_helper_cb, 0);
-  if(inpath("mozplugger-" VERSION))
-    helper_fname="mozplugger-" VERSION;
+  find_helper_file("mozplugger", find_plugger_helper_cb, 0);
+  if(inpath("mozplugger"))
+    helper_fname="mozplugger";
 
   if(!helper_fname)
     fprintf(stderr,"MozPlugger: Unable to find mozplugger-" VERSION "\n");
@@ -574,7 +574,7 @@ static int find_command(NPP instance,
 }
 
 /* Let netscape know things about mozplugger */
-NPError NPP_GetValue(void *future, NPPVariable variable, void *value)
+NPError NPP_GetValue(void *instance, NPPVariable variable, void *value)
 {
   NPError err = NPERR_NO_ERROR;
 
@@ -596,7 +596,7 @@ NPError NPP_GetValue(void *future, NPPVariable variable, void *value)
       "MozPlugger version "
       VERSION
       ", written by "
-      "<a href=http://fredrik.hubbe.net/>Fredrik Hbinette</a> "
+      "<a href=http://fredrik.hubbe.net/>Fredrik H&uuml;binette</a> "
       "<a href=mailto:hubbe@hubbe.net>&lt;hubbe@hubbe.net&gt</a> "
       "and Louis Bavoil "
       "<a href=mailto:bavoil@enseirb.fr>&lt;bavoil@enseirb.fr&gt</a>.<br>"
@@ -716,6 +716,9 @@ NPError NPP_NewStream(NPP instance,
   if (instance == NULL)
     return NPERR_INVALID_INSTANCE_ERROR;
 
+  if (THIS->pid1 != -1)
+    return NPERR_NO_ERROR;
+
   /* This is a stupid special case and should be coded into
    * mozpluggerc instead...
    */
@@ -736,23 +739,20 @@ NPError NPP_NewStream(NPP instance,
 
   D("Url is %s (seekable=%d)\n",stream->url,seekable);
   
-  if(!find_command(instance, 1))
-  {
-    if(!find_command(instance, 0))
+  if(!find_command(instance, 1) && !find_command(instance, 0))
     {
       if(!inpath("xmessage"))
-      {
-	NPN_Status(instance, "No approperiate application found!");
-	return NPERR_GENERIC_ERROR;
-      }else{
-	D("Using xmessage!!!\n");
-	/* Hard-coded default */
-	THIS->command="xmessage -buttons '' \"MozPlugger: No approperiate application for type $mimetype found!\"";
-	THIS->flags = H_REPEATCOUNT | H_FILL | H_SWALLOW | H_IGNORE_ERRORS;
-	THIS->winname="Xmessage";
-      }
+	{
+	  NPN_Status(instance, "No appropriate application found !");
+	  return NPERR_GENERIC_ERROR;
+	}else{
+	  D("Using xmessage!!!\n");
+	  /* Hard-coded default */
+	  THIS->command="xmessage -buttons '' \"MozPlugger: No appropriate application for type $mimetype found!\"";
+	  THIS->flags = H_REPEATCOUNT | H_FILL | H_SWALLOW | H_IGNORE_ERRORS;
+	  THIS->winname="Xmessage";
+	}
     }
-  }
 
   if((THIS->flags & H_STREAM) && strncasecmp(stream->url,"file:",5))
   {
@@ -768,7 +768,6 @@ NPError NPP_NewStream(NPP instance,
     
     if(!THIS->pid1)
     {
-      THIS->repeats=1;
       D("CHILD RUNNING run() [1]\n");
       run(instance, stream->url);
       exit(69);
@@ -790,10 +789,7 @@ int32 NPP_WriteReady(NPP instance, NPStream *stream)
   if (!instance)
     return 0;
   if (!tempfile)
-    {
-      NPP_DestroyStream(instance, stream, NPERR_NO_ERROR);
-      return 0;
-    }
+    return 0;
   return 0x7fffffff;
 }
 
@@ -830,13 +826,13 @@ void NPP_StreamAsFile(NPP instance,
     {
       D("CHILD RUNNING run() [7]\n");
 
-      if(!find_command(instance, 0))
+      if(!find_command(instance, 1) && !find_command(instance, 0))
 	{
 	  if(inpath("xmessage"))
 	    {
 	      D("Using xmessage!!!\n");
 	      /* Hard-coded default */
-	      THIS->command="xmessage -buttons '' \"MozPlugger: No approperiate application for type $mimetype found!\"";
+	      THIS->command="xmessage -buttons '' \"MozPlugger: No appropriate application for type $mimetype found!\"";
 	      THIS->flags = H_REPEATCOUNT | H_FILL | H_SWALLOW | H_IGNORE_ERRORS;
 	      THIS->winname="Xmessage";
 	    }else{
